@@ -25,6 +25,7 @@
 #include <array>
 #include <atomic>
 #include <cerrno>
+#include <csignal>
 #include <cstring>
 #include <ctime>
 #include <thread>
@@ -109,6 +110,12 @@ static bool ndServer_ClientRequest(FILE *hf) {
                   ndServer::ResponseCode::OK, "Ok.", jdata);
                 break;
 
+            case ndServer::CommandCode::RELOAD:
+                ndInstance::GetInstance().SendSignal(SIGHUP);
+                ndServer_ClientResponse(hf,
+                  ndServer::ResponseCode::OK, "Ok.", jdata);
+                break;
+
             case ndServer::CommandCode::GROUP_ADDR_ADD:
             case ndServer::CommandCode::GROUP_ADDR_DEL:
                 jdata["total"] = ssc.data_total;
@@ -289,6 +296,9 @@ void ndServer::Reload(const string &path_socket) {
     if (path_socket.empty() || path_socket != this->path_socket)
         Close();
 
+    if (! path_socket.empty() && path_socket == this->path_socket)
+        return;
+
     try {
         if (! path_socket.empty()) {
             ndSocketServerLocal *server = new ndSocketServerLocal(path_socket);
@@ -353,6 +363,8 @@ bool ndServerSaxConsumer::string(string_t &val) {
 
         if (strcasecmp(val.c_str(), "status") == 0)
             command = ndServer::CommandCode::STATUS;
+        else if (strcasecmp(val.c_str(), "reload") == 0)
+            command = ndServer::CommandCode::RELOAD;
         else if (strcasecmp(val.c_str(), "add-group-address") == 0)
             command = ndServer::CommandCode::GROUP_ADDR_ADD;
         else if (strcasecmp(val.c_str(), "remove-group-address") == 0 ||
